% Class file for Computer Science Technical Reports at the University of Houston
% Author: Ioannis Konstantinidis,
% Visual Computing Lab, Dept. of Computer Science, University of Houston, Houston, TX, USA

% Revision history
% 2004/11/03 v 1.1 is released
% footnote mark convention is now consistent with IEEE style guidelines
% (i.e., no marks are produced unless we use \authorrefmark{})
%
% 2004/10/15 UHCSTR v. 1.0 is released.


\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{UHCSTR}[2004/10/15 UH CS Technical Report v.~1.0]
\LoadClass[11pt,onecolumn,journal]{IEEEtran} % UHCSTR.cls is based on IEEEtran.cls.

\newif\ifpdf
\ifx\pdfoutput\undefined
   \pdffalse
\else
   \pdfoutput=1
   \pdftrue
\fi

\ifpdf
  \RequirePackage{times}
  \RequirePackage[pdftex]{graphicx}
  \RequirePackage[pdftex=true,backref]{hyperref}
  \pdfcompresslevel=9
\else
  \RequirePackage{graphicx,url}
\fi

\newcommand{\TRNumber}[1]{\def\TRNumberText{#1}}
\newcommand{\CoverTitle}[1]{\def\CoverTitleText{#1}}
\newcommand{\CoverAuthors}[1]{\def\CoverAuthorsText{#1}}
\newcommand{\CoverKeywords}[1]{\def\CoverKeywordsText{#1}}
\newcommand{\CoverAbstract}[1]{\def\CoverAbstractText{#1}}

\newcommand{\UHCSTechReport}{
% This command typesets the cover page and preamble
% of the document
  \renewcommand{\thefootnote}{} % This command forces footnote marks to disappear
  \setcounter{page}{0}
  \thispagestyle{empty}%
    \begin{center}
    \includegraphics[width=\columnwidth]{CSlogo}
    \mbox{}\\
        \textrm{ \Large \CoverTitleText\\
        \mbox{}\\
        \large \CoverAuthorsText  \\
        \mbox{}\\
         Department of Computer Science  \\
         University of Houston \\
         Houston, TX, 77204, USA
        \mbox{}\\
        \url{http://www.cs.uh.edu}\\
        \mbox{}\\
         Technical Report Number \TRNumberText \\
        \mbox{}\\
        \today \\
        \vspace*{1in}
        \textbf{ Keywords:} \CoverKeywordsText
        } % end textrm
    \end{center}
    \begin{center}
    \textrm{ \large \textbf{Abstract} }
    \end{center}
  \textrm{ \large \CoverAbstractText }
  \vspace*{\fill}
    \begin{center}
    \includegraphics[width=2.2cm]{UHlogo}
    \end{center}
  \vspace*{\fill}

% this takes care of the cover page
% now we typeset the preamble of the main document (title, abstract, keywords)

\title{\CoverTitleText}
\author{\CoverAuthorsText}
\date{\today}

\maketitle

\begin{abstract}
\CoverAbstractText
\end{abstract}

\begin{keywords}
\CoverKeywordsText
\end{keywords}

} % end command UHCSTechReport

% end of file UHCSTR.cls
